Crate volsungr

Crate volsungr 

Enums

PackageCompatMatchType
Specifies possible types of version matching from package to target rustc version

Functions

query_package
Determine the best compatible match for the given package and target rustc version